indigo_version

Type Alias indigo_version 

pub type indigo_version = c_uint;
Property, device or client version. Version value is used to map property or item names correctly or to trigger for version specific property handling. Do not use other than defined values!