#[repr(C)]pub struct indigo_client {
pub name: [c_char; 128],
pub is_remote: bool,
pub client_context: *mut c_void,
pub last_result: indigo_result,
pub version: indigo_version,
pub enable_blob_mode_records: *mut indigo_enable_blob_mode_record,
pub attach: Option<unsafe extern "C" fn(client: *mut indigo_client) -> indigo_result>,
pub define_property: Option<unsafe extern "C" fn(client: *mut indigo_client, device: *mut indigo_device, property: *mut indigo_property, message: *const c_char) -> indigo_result>,
pub update_property: Option<unsafe extern "C" fn(client: *mut indigo_client, device: *mut indigo_device, property: *mut indigo_property, message: *const c_char) -> indigo_result>,
pub delete_property: Option<unsafe extern "C" fn(client: *mut indigo_client, device: *mut indigo_device, property: *mut indigo_property, message: *const c_char) -> indigo_result>,
pub send_message: Option<unsafe extern "C" fn(client: *mut indigo_client, device: *mut indigo_device, message: *const c_char) -> indigo_result>,
pub detach: Option<unsafe extern "C" fn(client: *mut indigo_client) -> indigo_result>,
}Expand description
Client structure definition
Fields
name: [c_char; 128]< client name
is_remote: bool< is remote client
client_context: *mut c_void< any client specific data
last_result: indigo_result< result of last bus operation
version: indigo_version< client version
enable_blob_mode_records: *mut indigo_enable_blob_mode_record< enable blob mode
attach: Option<unsafe extern "C" fn(client: *mut indigo_client) -> indigo_result>callback called when client is attached to the bus
define_property: Option<unsafe extern "C" fn(client: *mut indigo_client, device: *mut indigo_device, property: *mut indigo_property, message: *const c_char) -> indigo_result>callback called when device broadcast property definition
update_property: Option<unsafe extern "C" fn(client: *mut indigo_client, device: *mut indigo_device, property: *mut indigo_property, message: *const c_char) -> indigo_result>callback called when device broadcast property value change
delete_property: Option<unsafe extern "C" fn(client: *mut indigo_client, device: *mut indigo_device, property: *mut indigo_property, message: *const c_char) -> indigo_result>callback called when device broadcast property removal
send_message: Option<unsafe extern "C" fn(client: *mut indigo_client, device: *mut indigo_device, message: *const c_char) -> indigo_result>callback called when device broadcast a message
detach: Option<unsafe extern "C" fn(client: *mut indigo_client) -> indigo_result>callback called when client is detached from the bus